@@ -34,5 +34,15 @@ module Debci
       pages = get_page_range(Integer(current_page), total_pages)
       Page.new(current_page, records, total_pages, pages)
     end
+
+    def pagination_params(page)
+      query = {}
+      request.env['rack.request.query_hash'].each do |key, value|
+        key = "#{key}[]".to_sym if value.is_a?(Array)
+        query[key] = value
+      end
+      query.merge!(page: page)
+      URI.encode_www_form(query)
+    end
   end
 end
