@@ -40,9 +40,7 @@ module Debci
         # FIXME make directory unique
         Dir.chdir(root) do
           FileUtils.mkdir_p('export')
-          File.open("export/#{pkg.name}.json", 'w') do |f|
-            f.write(Debci::Job.where(package: pkg).to_json)
-          end
+          File.write("export/#{pkg.name}.json", Debci::Job.where(package: pkg).to_json)
         end
         entries << "export/#{pkg.name}.json"
       end
@@ -58,7 +56,6 @@ module Debci
       end
     end
 
-
     class Import
 
       attr_reader :tarball, :root
@@ -99,9 +96,7 @@ module Debci
                   entry['run_id'] = new_id
                 end
               end
-              File.open(history, 'w') do |f|
-                f.write(JSON.pretty_generate(data))
-              end
+              File.write(history, JSON.pretty_generate(data))
               puts "# rewrite #{history}"
             end
           end
