@@ -7,16 +7,14 @@ module Debci
     def initialize(news)
       @feed = RSS::Maker.make('atom') do |feed|
         feed.channel.author = "#{distro_name} Continuous Integration"
-        feed.channel.updated = news.first && news.first.date || Time.parse('2020-04-18T21:17:00 UTC')
+        feed.channel.updated = (news.first && news.first.date) || Time.parse('2020-04-18T21:17:00 UTC')
         yield(feed) if block_given?
         insert_items(news, feed)
       end
     end
 
     def write(output)
-      File.open(output, 'w') do |f|
-        f.write(@feed.to_s.gsub('<summary>', '<summary type="html">'))
-      end
+      File.write(output, @feed.to_s.gsub('<summary>', '<summary type="html">'))
     end
 
     private
