@@ -10,10 +10,14 @@ module Debci
         Debci::HTML.update
       end
 
-      desc 'update-package PACKAGE [SUITE] [ARCHITECTURE]', 'Updates HTML for a given package, optionally only for the given suite and architecture'
-      def update_package(pkg, suite = nil, arch = nil)
+      desc 'update-package PACKAGE', 'Updates HTML for a given package'
+      def update_package(pkg)
         package = Debci::Package.where(name: pkg).first
-        Debci::HTML.update_package(package, suite, arch)
+        Debci::HTML.update_package(package)
+      end
+
+      def self.exit_on_failure?
+        true
       end
     end
   end
