@@ -1,6 +1,7 @@
 require 'debci'
 require 'debci/user'
 require 'debci/amqp'
+require 'debci/backend'
 require 'debci/db'
 require 'debci/package'
 require 'debci/package_status'
@@ -149,8 +150,7 @@ module Debci
           job.last_pass_version = job.last_pass.version
         end
 
-        base = Pathname(Debci.config.autopkgtest_basedir)
-        dest = base / job.suite / job.arch / job.package.prefix / job.package.name / id
+        dest = job.autopkgtest_data_dir
         dest.parent.mkpath
 
         # remove destination directory if it exists; this can happen is a
@@ -160,9 +160,10 @@ module Debci
         FileUtils.cp_r src, dest
         Dir.chdir dest do
           artifacts = Dir['*'] - ['log.gz']
-          cmd = ['tar', '-caf', 'artifacts.tar.gz', '--remove-files', *artifacts]
+          cmd = ['tar', '-caf', 'artifacts.tar.gz', '--remove-files', '--', *artifacts]
           system(*cmd) || raise('Command failed: %<cmd>s' % { cmd: cmd.join(' ') })
         end
+        job.calculate_file_sizes!
 
         job.save!
 
@@ -171,6 +172,20 @@ module Debci
       end
     end
 
+    def autopkgtest_data_path
+      @autopkgtest_data_path ||= File.join(suite, arch, package.prefix, package.name, id.to_s)
+    end
+
+    def autopkgtest_data_dir
+      @autopkgtest_data_dir ||= Pathname(Debci.config.autopkgtest_basedir) / autopkgtest_data_path
+    end
+
+    def calculate_file_sizes!
+      dir = self.autopkgtest_data_dir
+      self.log_size = (dir / 'log.gz').size
+      self.artifacts_size = (dir / 'artifacts.tar.gz').size
+    end
+
     def self.status(exit_code)
       case exit_code
       when 0
@@ -245,26 +260,38 @@ module Debci
       end
       Array(self.pin_packages).each do |pin|
         *pkgs, suite = pin
-        pkgs.each do |pkg|
-          parameters << "pin-packages:#{suite}=#{pkg}"
-        end
+        parameters << "pin-packages:#{suite}=#{pkgs.join(',')}"
       end
-      Array(self.extra_apt_sources).each do |src|
-        parameters << "extra-apt-source:#{Base64.strict_encode64(src)}"
+      Array(self.extra_apt_sources).each do |name|
+        src = Debci.extra_apt_sources_list.find(name)
+        parameters << "extra-apt-source:#{Base64.strict_encode64(src.entry)}"
+        parameters << "signing-key:#{Base64.strict_encode64(src.signing_key)}" if src.signing_key
       end
       parameters
     end
 
     def enqueue(priority = 5)
-      queue = if package.backend.nil?
-                Debci::AMQP.get_queue(arch)
-              else
-                Debci::AMQP.get_queue(arch, package.backend)
-              end
+      backend = Debci::Backend.select(package, arch)
+      queue = Debci::AMQP.get_queue(arch, backend)
       parameters = enqueue_parameters
       queue.publish("%s %s %s" % [package.name, suite, parameters.join(' ')], priority: priority)
     end
 
+    def retry
+      new_job = Debci::Job.create!(
+        package: self.package,
+        suite: self.suite,
+        arch: self.arch,
+        requestor: self.requestor,
+        trigger: self.trigger,
+        pin_packages: self.pin_packages,
+        is_private: self.is_private,
+        extra_apt_sources: self.extra_apt_sources
+      )
+      new_job.enqueue
+      new_job
+    end
+
     def to_s
       "%s %s/%s (%s)" % [package.name, suite, arch, status || 'pending']
     end
