@@ -1,7 +1,7 @@
 require 'json'
 require 'securerandom'
 
-require 'debci/app'
+require 'debci/auth_app'
 require 'debci/test_handler'
 require 'debci/html_helpers'
 require 'debci/validators'
@@ -9,7 +9,7 @@ require 'omniauth'
 require 'omniauth-gitlab'
 
 module Debci
-  class SelfService < Debci::App
+  class SelfService < Debci::AuthApp
     include Debci::TestHandler
     include Debci::HTMLHelpers
     include Debci::Validators::APTSource
@@ -25,7 +25,7 @@ module Debci
                redirect_url: "#{Debci.config.url_base}/user/auth/gitlab/callback",
                scope: "read_user",
                client_options: {
-                 site: 'https://salsa.debian.org/api/v4/'
+                 site: 'https://salsa.debian.org'
                }
     end
 
@@ -42,19 +42,8 @@ module Debci
       set :archs, Debci.config.arch_list
     end
 
-    enable :sessions
-    set :session_secret, Debci.config.session_secret || SecureRandom.hex(64)
-
     before do
-      authenticate! unless request.path =~ %r{/user/[^/]+/jobs/?$} || request.path == '/user/login' || request.path =~ %r{/user/auth/\w*}
-      @user = session[:user]
-    end
-
-    def authenticate!
-      return unless session[:user].nil?
-      session[:original_url] = request.path
-      redirect('/user/login')
-      halt
+      authenticate! unless request.path == '/user/login' || request.path =~ %r{/user/auth/\w*}
     end
 
     get '/' do
@@ -85,7 +74,7 @@ module Debci
     end
 
     get '/logout' do
-      session[:user] = nil
+      session[:user_id] = nil
       redirect '/'
     end
 
@@ -115,19 +104,16 @@ module Debci
         test_obj = {
           'trigger' => trigger,
           'package' => package,
-          'is_private' => is_private
+          'is_private' => is_private,
+          'extra-apt-sources' => extra_apt_sources
         }
-        test_obj['extra-apt-sources'] = []
-        extra_apt_sources.each do |extra_apt_source|
-          test_obj['extra-apt-sources'].push(Debci.extra_apt_sources_list.find(extra_apt_source).entry)
-        end
         test_obj['pin-packages'] = []
         pin_packages.each do |pin_package|
           pin_package = pin_package.split(/,\s*/)
           test_obj['pin-packages'].push(pin_package)
         end
         test_request = {
-          'archs' => archs,
+          'arch' => archs,
           'suite' => suite,
           'tests' => [test_obj]
         }
@@ -164,17 +150,7 @@ module Debci
     post '/:user/retry/:run_id' do
       run_id = params[:run_id]
       j = get_job_to_retry(run_id)
-      job = Debci::Job.create!(
-        package: j.package,
-        suite: j.suite,
-        arch: j.arch,
-        requestor: j.requestor,
-        trigger: j.trigger,
-        pin_packages: j.pin_packages,
-        is_private: j.is_private,
-        extra_apt_sources: j.extra_apt_sources
-      )
-      self.enqueue(job)
+      j.retry
       201
     end
 
@@ -230,7 +206,7 @@ module Debci
       query = {
         requestor: user
       }
-      disable_private_filter = (session[:user] != user)
+      disable_private_filter = (@user != user)
       is_private_filter = disable_private_filter ? false : params[:is_private]
       query[:is_private] = is_private_filter unless is_private_filter.nil?
       query[:arch] = arch_filter if arch_filter
@@ -254,18 +230,7 @@ module Debci
       # pagination
       results = get_page_params(@history, params[:page], 20)
 
-      # generate query params
-      query_params = {}
-      params.each do |key, val|
-        next if [:user, :page].include?(key.to_sym)
-        case val
-        when Array then query_params["#{key}[]"] = val
-        else
-          query_params[key] = val
-        end
-      end
-
-      erb :self_service_history, locals: { query_params: query_params, arch_filter: arch_filter, suite_filter: suite_filter, package_filter: package_filter, trigger_filter: trigger_filter,
+      erb :self_service_history, locals: { arch_filter: arch_filter, suite_filter: suite_filter, package_filter: package_filter, trigger_filter: trigger_filter,
                                            is_private_filter: is_private_filter, disable_private_filter: disable_private_filter, results: results }
     end
 
@@ -282,16 +247,6 @@ module Debci
       [200, erb(:publish)]
     end
 
-    def get_job_to_retry(run_id)
-      begin
-        job = Debci::Job.find(run_id)
-      rescue ActiveRecord::RecordNotFound
-        halt(400, "Job ID not known: #{run_id}")
-      end
-      halt(403, "Package #{job.package.name} is in the REJECT list and cannot be retried") if Debci.reject_list.include?(job.package, suite: job.suite, arch: job.arch)
-      job
-    end
-
     def get_same_pending_jobs(job)
       Debci::Job.pending.where(
         package_id: job.package_id,
@@ -309,7 +264,7 @@ module Debci
         c.username = username
       end
       user.update(username: username) if user.username != username
-      session[:user] = user
+      session[:user_id] = user.id
       original_url = session[:original_url]
       session.delete(:original_url)
       redirect(original_url || "/user/#{user.username}")
