@@ -84,5 +84,15 @@ module Debci
         self.enqueue(job, priority)
       end
     end
+
+    def get_job_to_retry(run_id)
+      begin
+        job = Debci::Job.find(run_id)
+      rescue ActiveRecord::RecordNotFound
+        halt(400, "Job ID not known: #{run_id}")
+      end
+      halt(403, "Package #{job.package.name} is in the REJECT list and cannot be retried") if Debci.reject_list.include?(job.package, suite: job.suite, arch: job.arch)
+      job
+    end
   end
 end
