@@ -43,7 +43,14 @@ debci_suite=${debci_suite:-unstable}
 debci_suite_list=${debci_suite_list:-${debci_suite}}
 debci_arch=${debci_arch:-$(dpkg --print-architecture)}
 debci_arch_list="${debci_arch_list:-${debci_arch}}"
-debci_mirror=${debci_mirror:-${MIRROR:-http://deb.debian.org/debian}}
+if [ -n "${debci_mirror:-}" ]; then
+  # This is used in lxc by the lxc-debian template, and by autopkgtest-build-*
+  # Only set if debci_mirror was explicitly set; otherwise, let tools use their
+  # own default
+  export MIRROR="${debci_mirror}"
+else
+  debci_mirror=http://deb.debian.org/debian
+fi
 debci_backend=${debci_backend:-lxc}
 debci_backend_list=${debci_backend_list:-${debci_backend}}
 debci_data_basedir=${debci_data_basedir:-$(readlink -f "${debci_base_dir}/data")}
@@ -78,7 +85,7 @@ usage_shared_options="Common options:
                             (default: ${debci_default_config_dir})
   -a, --arch ARCH           selects the architecture to run tests for
                             (default: host architecture)
-  -n, --backend BACKEND     selects the backends to run tests on
+  -b, --backend BACKEND     selects the backends to run tests on
                             (default: lxc)
   -s, --suite SUITE         selects suite to run tests for
                             (default: unstable)
@@ -144,9 +151,6 @@ for arg in "$@"; do
   fi
 done
 
-# This is used in lxc by the lxc-debian template, and by autopkgtest-build-*
-export MIRROR="${debci_mirror}"
-
 # shellcheck disable=SC2142
 alias prepare_args='while [ "$1" != "--" ]; do shift; done; shift'
 
