@@ -69,7 +69,8 @@ jQuery(function($) {
             position: 'nw'
           },
           xaxis: {
-            mode: "time"
+            mode: "time",
+            timeBase: "milliseconds"
           },
           yaxis: {
             min: 0
@@ -85,6 +86,7 @@ jQuery(function($) {
           colors: [ '#8ae234' ],
           xaxis: {
             mode: 'time',
+            timeBase: "milliseconds"
           },
           yaxis: {
             min: 0,
