@@ -21,19 +21,7 @@ describe Debci::Config do
       it "knows about #{key}" do
         expect(config.send(key)).to_not be_a(String)
       end
-    elsif [:data_retention_days].include?(key)
-      it "knows about #{key}" do
-        expect(config.send(key)).to be_a(Integer)
-      end
-    elsif [:failing_packages_per_page].include?(key)
-      it "knows about #{key}" do
-        expect(config.send(key)).to be_a(Integer)
-      end
-    elsif [:status_visible_days].include?(key)
-      it "knows about #{key}" do
-        expect(config.send(key)).to be_a(Integer)
-      end
-    elsif [:slow_tests_duration_minutes].include?(key)
+    elsif [:data_retention_days, :failing_packages_per_page, :status_visible_days, :slow_tests_duration_minutes].include?(key)
       it "knows about #{key}" do
         expect(config.send(key)).to be_a(Integer)
       end
@@ -48,9 +36,9 @@ describe Debci::Config do
   end
 
   it 'reads entry set to empty string in config file as nil' do
-    @io.reopen("data_basedir=/path/to/data\nartifacts_url_base=\n")
+    @io.reopen("url_base=https://ci.debian.net\nartifacts_url_base=\n")
     expect(config.artifacts_url_base).to be_nil
-    expect(config.data_basedir).to eq('/path/to/data')
+    expect(config.url_base).to eq('https://ci.debian.net')
   end
 
   it 'splits at the first equal sign only' do
