@@ -7,9 +7,9 @@ describe Debci::HTML::CLI do
     Debci::HTML::CLI.new.update
   end
 
-  it 'calls update_package on update-pakckage' do
+  it 'calls update_package on update-package' do
     pkg = Debci::Package.create!(name: 'foo')
-    expect(Debci::HTML).to receive(:update_package).with(pkg, nil, nil)
+    expect(Debci::HTML).to receive(:update_package).with(pkg)
     Debci::HTML::CLI.new.update_package('foo')
   end
 end
