@@ -4,8 +4,6 @@ require 'spec_helper'
 require 'debci/html'
 
 describe Debci::HTML do
-  include_context 'tmpdir'
-
   before(:each) do
     allow_any_instance_of(Debci::Config).to receive(:html_dir).and_return("#{tmpdir}/html")
     allow_any_instance_of(Debci::Config).to receive(:data_basedir).and_return("#{tmpdir}/data")
@@ -17,7 +15,6 @@ describe Debci::HTML do
   context 'generating global pages' do
     before(:each) { Debci::HTML.update }
     it('produces home page') { expect(html / 'index.html').to exist }
-    it('produces status page') { expect(html / 'status/index.html').to exist }
   end
 
   let(:package) { Debci::Package.create!(name: 'foobar') }
@@ -78,52 +75,6 @@ describe Debci::HTML do
     end
   end
 
-  context 'producing status pages' do
-    let(:h) { Debci::HTML.new }
-    let(:reject_list_data) do
-      { "foobar" => { "*" => { "*" => { "*" => "" } } } }
-    end
-    it 'produces rejectlist page' do
-      allow_any_instance_of(Debci::RejectList).to receive(:data).and_return(reject_list_data)
-      h.reject_list
-
-      page = html / 'status/reject_list/index.html'
-      expect(page).to exist
-    end
-  end
-
-  context 'package pages' do
-    before(:each) do
-      Debci::HTML.update_package(job.package)
-    end
-
-    let(:pkgdata) { data / "packages/unstable/#{arch}/f/foobar" }
-
-    it 'produces history.json' do
-      history_json = pkgdata / 'history.json'
-      expect(history_json).to exist
-      data = ::JSON.parse(history_json.read)
-      expect(data.size).to eq(1)
-    end
-
-    it 'produces latest.json' do
-      latest_json = pkgdata / 'latest.json'
-      expect(latest_json).to exist
-      data = ::JSON.parse(latest_json.read)
-      expect(data).to be_a(Hash)
-    end
-
-    it 'links to latest-autopkgtest' do
-      link = pkgdata / 'latest-autopkgtest'
-      expect(link).to be_a_symlink
-    end
-
-    it 'replaces latest-autopkgtest' do
-      # a second time
-      Debci::HTML.update_package(job.package)
-    end
-  end
-
   context 'producing package news feed' do
     it 'produces feed with news' do
       first = job
