@@ -5,11 +5,9 @@ require 'debci/job'
 require 'debci/package'
 
 describe Debci::Job do
-  include_context 'tmpdir'
-
   let(:package) { Debci::Package.create!(name: 'mypackage') }
   let(:theuser) { Debci::User.create!(username: 'user') }
-  let(:new_job) { Debci::Job.create!(package: package, requestor: theuser) }
+  let(:new_job) { Debci::Job.create!(package: package, arch: "arm64", requestor: theuser) }
 
   it 'sets created_at' do
     expect(new_job.created_at).to_not be_nil
@@ -61,20 +59,60 @@ describe Debci::Job do
 
     it 'handles multiple pinned packages' do
       job = Debci::Job.new(pin_packages: [["src:foo", "src:bar", "unstable"]])
-      expect(job.enqueue_parameters).to include('pin-packages:unstable=src:foo')
-      expect(job.enqueue_parameters).to include('pin-packages:unstable=src:bar')
+      expect(job.enqueue_parameters).to include('pin-packages:unstable=src:foo,src:bar')
+    end
+
+    before do
+      bullseye_security_signing_key =
+        '-----BEGIN PGP PUBLIC KEY BLOCK-----
+      mQINBEo1mTQBEAD29YIKM0hM2IsB+TzBOpQja6h5hJ1gVeP7IWhC8E11jwaaoP1K
+      SXESKFMVPt0es0aCSDftm5TVTvLl08MG9fZBFT8pERfkWTEWWhY1MJ28sV8PRBHf
+      hN0mv5aduvgVx32+aCD0mWhI/3XHObf6c/X9WMwEaH+6A9UFiXRCyflra9YOfHU
+      inXj5aYllc2UNiNxPhJ5sQTv97hdVbb/dFa+t9A2LFgPADbwUW+ShJN8zGR3XMne
+      lXTcOgPhBadiNPPi8PztfOgcUk/NqZ5H4i0cXXbZB6leWcGMMMiWNexapgea/Hvp
+      aXT2kSIug7OySFXM4nhM4xGo426+r9QHx1dzndHP5AW+WRuJmi3hMEdj22ifIFrV
+      XtwovTb6/R2nG7WLVSHKg1AuFvIfG1RrTaVUVMcXVGX83CB2qKjfMHFRyMKUxoK7
+      cZZkgD+sst47L+P3MlrRPfuB6selEySIrcwXTxFiuhLf74Zc8AZZeOi5ae2GObGr
+      b40wIT4HpJZO9M2YfZkMcnFsAqB8D4tPz9OjXiZdqNrXBMKJo0nsOFsYqkOCpnXP
+      ic4HQvmEaEWzNuPlWFH54AQf3zAWMoawLXOfgAOYAc8gf1dxYOTMJEBIplBBj8ch
+      ...
+      -----END PGP PUBLIC KEY BLOCK-----'
+      allow(Debci.extra_apt_sources_list).to receive(:find)
+        .with('experimental')
+        .and_return(Debci::ExtraAptSource.new('deb http://deb.debian.org/debian experimental main'))
+      allow(Debci.extra_apt_sources_list).to receive(:find)
+        .with('bullseye-security')
+        .and_return(Debci::ExtraAptSource.new('deb http://security.debian.org/debian-security bullseye-security main', [], bullseye_security_signing_key))
     end
 
     it 'encodes each extra-apt-sources string to base64' do
-      job = Debci::Job.new(extra_apt_sources: ["deb http://deb.debian.org/debian experimental main"])
+      job = Debci::Job.new(extra_apt_sources: ["experimental"])
       expect(job.enqueue_parameters).to include(%r'extra-apt-source:([A-Za-z0-9+/]{4})*([A-Za-z0-9+/]{3}=|[A-Za-z0-9+/]{2}==)?')
     end
 
     it 'handles multiple extra-apt-sources' do
-      job = Debci::Job.new(extra_apt_sources: ["deb http://deb.debian.org/debian experimental main", "deb http://security.debian.org/debian-security bullseye-security main"])
+      job = Debci::Job.new(extra_apt_sources: ["experimental", "bullseye-security"])
       expect(job.enqueue_parameters).to include("extra-apt-source:#{Base64.strict_encode64('deb http://deb.debian.org/debian experimental main')}")
       expect(job.enqueue_parameters).to include("extra-apt-source:#{Base64.strict_encode64('deb http://security.debian.org/debian-security bullseye-security main')}")
     end
+
+    it 'enqueues signing-key if present for an extra-apt-source' do
+      job = Debci::Job.new(extra_apt_sources: ["experimental", "bullseye-security"])
+      expect(job.enqueue_parameters.to_s.scan('signing-key').size).to eq(1)
+    end
+
+    it 'encodes signing-key of extra-apt-source to base64' do
+      job = Debci::Job.new(extra_apt_sources: ["bullseye-security"])
+      expect(job.enqueue_parameters).to include(%r'signing-key:([A-Za-z0-9+/]{4})*([A-Za-z0-9+/]{3}=|[A-Za-z0-9+/]{2}==)?')
+    end
+
+    it 'publishes message to the queue' do
+      queue = double("Queue")
+      expect(Debci::AMQP).to receive(:get_queue).and_return(queue)
+      expect(queue).to receive(:publish)
+
+      new_job.enqueue
+    end
   end
 
   let(:suite) { 'unstable' }
@@ -85,16 +123,16 @@ describe Debci::Job do
     file = Tempfile.new('foo')
     file.write(
       {
-        'package': package.name,
-        'run_id': job.run_id,
-        'status': 'pass',
-        'version': '1.0-1',
-        'duration_seconds': 11,
-        'date': '2018-09-09 20:40:00',
-        'last_pass_date': '2018-01-09 20:40:00',
-        'last_pass_version': '0.9-1',
-        'message': 'bla bla bla',
-        'previous_status': 'fail'
+        package: package.name,
+        run_id: job.run_id,
+        status: 'pass',
+        version: '1.0-1',
+        duration_seconds: 11,
+        date: '2018-09-09 20:40:00',
+        last_pass_date: '2018-01-09 20:40:00',
+        last_pass_version: '0.9-1',
+        message: 'bla bla bla',
+        previous_status: 'fail'
       }.to_json
     )
     file.close
@@ -118,21 +156,21 @@ describe Debci::Job do
     file = Tempfile.new('foo')
     file.write(
       {
-        'package': 'bar',
-        'run_id': job.run_id,
-        'status': 'pass',
-        'version': '1.0-1',
-        'duration_seconds': 11,
-        'date': '2018-09-09 20:40:00',
-        'last_pass_date': '2018-01-09 20:40:00',
-        'last_pass_version': '0.9-1',
-        'message': 'bla bla bla',
-        'previous_status': 'fail'
+        package: 'bar',
+        run_id: job.run_id,
+        status: 'pass',
+        version: '1.0-1',
+        duration_seconds: 11,
+        date: '2018-09-09 20:40:00',
+        last_pass_date: '2018-01-09 20:40:00',
+        last_pass_version: '0.9-1',
+        message: 'bla bla bla',
+        previous_status: 'fail'
       }.to_json
     )
     file.close
 
-    expect(-> { Debci::Job.import(file.path) }).to raise_error(Debci::Job::InvalidStatusFile)
+    expect { Debci::Job.import(file.path) }.to raise_error(Debci::Job::InvalidStatusFile)
     job.reload
     expect(job.status).to be_nil
   end
@@ -294,6 +332,15 @@ describe Debci::Job do
       expect(contents).to eq(["artifacts.tar.gz", "log.gz"])
     end
 
+    it 'does not choke on files beginning with a dash' do
+      testname = "-ureq-2:gzip.stdout"
+      (Pathname(incoming) / testname).write("HELLO")
+      id = job.id.to_s
+      received = Pathname(Debci.config.autopkgtest_basedir) / "unstable/amd64/m/mypackage" / id
+      files = `tar taf #{received}/artifacts.tar.gz`.split
+      expect(files).to include(testname)
+    end
+
     it 'recovers from an interrupted receiving' do
       FileUtils.mkdir_p incoming
       id = original_job.id.to_s
@@ -303,6 +350,11 @@ describe Debci::Job do
       job
     end
 
+    it 'calculates size of files' do
+      expect(job.log_size).to eq(243)
+      expect(job.artifacts_size).to be_an(Integer)
+    end
+
     let(:second_original_job) do
       Debci::Job.create!(
         package: package,
@@ -316,9 +368,9 @@ describe Debci::Job do
       second_incoming = File.join(tmpdir, 'autopkgtest-incoming', second_original_job.id.to_s)
       FileUtils.cp_r 'spec/debci/job_spec/autopkgtest-incoming', second_incoming
       FileUtils.touch(File.join(second_incoming, 'duration'), mtime: Time.now)
-      File.open(File.join(second_incoming, 'exitcode'), 'w') { |f| f.write('4') }
-      File.open(File.join(second_incoming, 'worker'), 'w') { |f| f.write('ci-worker-1') }
-      File.open(File.join(second_incoming, 'testpkg-version'), 'w') { |f| f.write('foobar 99-1') }
+      File.write(File.join(second_incoming, 'exitcode'), '4')
+      File.write(File.join(second_incoming, 'worker'), 'ci-worker-1')
+      File.write(File.join(second_incoming, 'testpkg-version'), 'foobar 99-1')
       Debci::Job.receive(second_incoming)
     end
 
@@ -515,4 +567,22 @@ describe Debci::Job do
       expect { Debci::Job.create!(package: package, suite: 'unstable', arch: 'amd64', status: 'pass', date: Time.now, requestor: theuser) }.to_not raise_error
     end
   end
+
+  context 'determining expiration' do
+    it 'is expired after data retention period' do
+      allow_any_instance_of(Debci::Config).to receive(:data_retention_days).and_return(90)
+      job = Debci::Job.new(date: Time.now - 91.days)
+      expect(job).to be_expired
+    end
+    it 'is not expired if recent' do
+      allow_any_instance_of(Debci::Config).to receive(:data_retention_days).and_return(90)
+      job = Debci::Job.new(date: Time.now - 1.day)
+      expect(job).to_not be_expired
+    end
+    it 'is not expired without a data retention period' do
+      allow_any_instance_of(Debci::Config).to receive(:data_retention_days).and_return(nil)
+      job = Debci::Job.new(date: Time.now - 1.year)
+      expect(job).to_not be_expired
+    end
+  end
 end
