@@ -2,11 +2,12 @@ require "spec_helper"
 require 'spec_mock_server'
 require 'debci'
 require 'debci/self_service'
-require 'rack/test'
 require 'json'
 
 describe Debci::SelfService do
-  include Rack::Test::Methods
+  include_context 'no-rabbitmq'
+
+  include WebAppHelper
 
   class SelfService < Debci::SelfService
     set :raise_errors, true
@@ -24,16 +25,6 @@ describe Debci::SelfService do
     temp_test_file
   end
 
-  def login(username, uid = nil)
-    uid ||= username.hash % 1000
-    OmniAuth.config.mock_auth[:gitlab] = OmniAuth::AuthHash.new({
-      provider: 'gitlab',
-      uid: uid,
-      info: OmniAuth::AuthHash::InfoHash.new({ username: username })
-    })
-    get '/user/auth/gitlab/callback'
-  end
-
   let(:suite) { Debci.config.suite }
   let(:arch) { Debci.config.arch }
 
@@ -144,12 +135,12 @@ describe Debci::SelfService do
       expect(job.is_private).to eq(false)
     end
 
-    it "accepts name of extra_apt_sources's names and passes its entry for job " do
+    it "passes extra_apt_sources to job" do
       post '/user/foo@bar.com/test/submit', pin_packages: '', trigger: 'test_trigger', package: 'test-package', suite: suite, arch: [arch],
                                             extra_apt_sources: ['bullseye-fasttrack']
       expect(last_response.status).to eq(201)
       job = Debci::Job.last
-      expect(job.extra_apt_sources).to eq(["deb https://fasttrack.debian.net/debian-fasttrack/ bullseye-fasttrack main contrib"])
+      expect(job.extra_apt_sources).to eq(["bullseye-fasttrack"])
     end
 
     it 'should return error when submitting form with invalid apt source value' do
@@ -197,15 +188,15 @@ describe Debci::SelfService do
     it 'submits a task successfully on a valid json file upload' do
       test_json = [
         {
-          "suite": suite,
-          "arch": [arch],
-          "tests": [
+          suite: suite,
+          arch: [arch],
+          tests: [
             {
-              "trigger": "testing",
-              "package": "autodep8",
-              "pin-packages": [["src:bar", "unstable"], ["foo", "src:bar", "stable"]],
-              "is_private": true,
-              "extra_apt_sources": ["bullseye-fasttrack"]
+              trigger: "testing",
+              package: "autodep8",
+              'pin-packages': [["src:bar", "unstable"], ["foo", "src:bar", "stable"]],
+              is_private: true,
+              extra_apt_sources: ["bullseye-fasttrack"]
             }
           ]
         }
@@ -229,13 +220,13 @@ describe Debci::SelfService do
       test_json = [
         {
           # invalid suite
-          "suite": "xyz",
-          "arch": ["arm64", arch],
-          "tests": [
+          suite: "xyz",
+          arch: ["arm64", arch],
+          tests: [
             {
-              "trigger": "testing",
-              "package": "autodep8",
-              "pin-packages": [["src:bar", "unstable"], ["foo", "src:bar", "stable"]]
+              trigger: "testing",
+              package: "autodep8",
+              'pin-packages': [["src:bar", "unstable"], ["foo", "src:bar", "stable"]]
             }
           ]
         }
@@ -250,14 +241,14 @@ describe Debci::SelfService do
     it 'should return error with an invalid arch' do
       test_json = [
         {
-          "suite": "unstable",
+          suite: "unstable",
           # invalid arch
-          "arch": ["xyz", arch],
-          "tests": [
+          arch: ["xyz", arch],
+          tests: [
             {
-              "trigger": "testing",
-              "package": "autodep8",
-              "pin-packages": [["src:bar", "unstable"], ["foo", "src:bar", "stable"]]
+              trigger: "testing",
+              package: "autodep8",
+              'pin-packages': [["src:bar", "unstable"], ["foo", "src:bar", "stable"]]
             }
           ]
         }
@@ -272,12 +263,12 @@ describe Debci::SelfService do
     it 'should not crash on missing arch' do
       test_json = [
         {
-          "suite": "unstable",
-          "tests": [
+          suite: "unstable",
+          tests: [
             {
-              "trigger": "testing",
-              "package": "autodep8",
-              "pin-packages": [["src:bar", "unstable"], ["foo", "src:bar", "stable"]]
+              trigger: "testing",
+              package: "autodep8",
+              'pin-packages': [["src:bar", "unstable"], ["foo", "src:bar", "stable"]]
             }
           ]
         }
@@ -292,13 +283,13 @@ describe Debci::SelfService do
     it 'should take is_private as false if not given' do
       test_json = [
         {
-          "suite": suite,
-          "arch": [arch],
-          "tests": [
+          suite: suite,
+          arch: [arch],
+          tests: [
             {
-              "trigger": "testing",
-              "package": "autodep8",
-              "pin-packages": [["src:bar", "unstable"], ["foo", "src:bar", "stable"]],
+              trigger: "testing",
+              package: "autodep8",
+              'pin-packages': [["src:bar", "unstable"], ["foo", "src:bar", "stable"]],
             }
           ]
         }
@@ -313,12 +304,12 @@ describe Debci::SelfService do
     it 'should return error for invalid is_private value' do
       test_json = [
         {
-          "suite": suite,
-          "arch": [arch],
-          "tests": [
+          suite: suite,
+          arch: [arch],
+          tests: [
             {
-              "package": "autodep8",
-              "is_private": "abc"
+              package: "autodep8",
+              is_private: "abc"
             }
           ]
         }
@@ -333,12 +324,12 @@ describe Debci::SelfService do
     it 'should return error for invalid extra-apt-sources value' do
       test_json = [
         {
-          "suite": suite,
-          "arch": [arch],
-          "tests": [
+          suite: suite,
+          arch: [arch],
+          tests: [
             {
-              "package": "autodep8",
-              "extra-apt-sources": ["bullseye-backports-staging"]
+              package: "autodep8",
+              'extra-apt-sources': ["bullseye-backports-staging"]
             }
           ]
         }
@@ -397,6 +388,8 @@ describe Debci::SelfService do
         package = Debci::Package.find_or_create_by!(name: job.delete(:package))
         Debci::Job.create(job.merge(package: package))
       end
+
+      login(theuser.username)
     end
 
     it 'displays correct results with package filter' do
@@ -457,7 +450,6 @@ describe Debci::SelfService do
     end
 
     it "displays correct results with is_private filter for the logged-in user's history" do
-      login(theuser.username)
       get "/user/#{theuser.username}/jobs", is_private: ["true"]
       expect(last_response.body).to match('mypackage/0.0.3')
       expect(last_response.body).to_not match('testpackage/0.0.2')
