@@ -101,12 +101,13 @@ start_rabbitmq_server() {
   mkdir -p $TEST_RABBIT_SERVER_DIR/log
   export RABBITMQ_NODENAME=$(basename "${TEST_RABBIT_SERVER_DIR}")
   export RABBITMQ_NODE_PORT=$TEST_RABBIT_PORT
+  echo "management.tcp.port = 1${TEST_RABBIT_PORT}" > "${TEST_RABBIT_SERVER_DIR}/rabbitmq.conf"
   env RABBITMQ_MNESIA_BASE=$TEST_RABBIT_SERVER_DIR/mnesia \
     RABBITMQ_LOG_BASE=$TEST_RABBIT_SERVER_DIR/log \
     RABBITMQ_SCHEMA_DIR=$TEST_RABBIT_SERVER_DIR/schema \
     RABBITMQ_GENERATED_CONFIG_DIR=$TEST_RABBIT_SERVER_DIR/config \
     RABBITMQ_NODE_IP_ADDRESS=127.0.0.1 \
-    RABBITMQ_CONFIG_FILE=/dev/null \
+    RABBITMQ_CONFIG_FILE=$TEST_RABBIT_SERVER_DIR/rabbitmq.conf \
     HOME=$TEST_RABBIT_SERVER_DIR \
     /usr/lib/rabbitmq/bin/rabbitmq-server > $TEST_RABBIT_SERVER_DIR/log/output.txt 2>&1 &
   TEST_RABBIT_SERVER_PID=$!
