@@ -5,7 +5,6 @@ set -e
 # Note the line below: this script is for development only. DO NOT EVER use
 # this script for a production deployment.
 export FAKE_CERTIFICATE_USER=$USER
-export debci_session_secret=$(echo "debci:$(cat /etc/machine-id)" | awk '{print($1)}')
 
 case $# in
   0)
@@ -20,6 +19,7 @@ case $# in
 esac
 
 echo "I: Web UI at http://localhost:$port/"
+echo "I: Web UI at https://localhost:$((port + 1))/"
 echo "I: Hit Control+C to stop"
 echo ""
 exec rerun \
@@ -28,4 +28,4 @@ exec rerun \
   --background \
   --dir lib \
   -p '**/*.rb' -- \
-  rackup --quiet --include lib --port="$port" --host=0.0.0.0
+  puma --silent --quiet --include lib --bind=tcp://0.0.0.0:${port} --bind=ssl://0.0.0.0:$((port + 1)) config.ru
